(function (factory) {
    typeof define === 'function' && define.amd ? define(factory) :
    factory();
}((function () { 'use strict';

    function invariant(condition, message, Err) {
        if (Err === void 0) { Err = Error; }
        if (!condition) {
            throw new Err(message);
        }
    }

    // https://tc39.es/ecma402/#sec-issanctionedsimpleunitidentifier
    var SANCTIONED_UNITS = [
        'angle-degree',
        'area-acre',
        'area-hectare',
        'concentr-percent',
        'digital-bit',
        'digital-byte',
        'digital-gigabit',
        'digital-gigabyte',
        'digital-kilobit',
        'digital-kilobyte',
        'digital-megabit',
        'digital-megabyte',
        'digital-petabyte',
        'digital-terabit',
        'digital-terabyte',
        'duration-day',
        'duration-hour',
        'duration-millisecond',
        'duration-minute',
        'duration-month',
        'duration-second',
        'duration-week',
        'duration-year',
        'length-centimeter',
        'length-foot',
        'length-inch',
        'length-kilometer',
        'length-meter',
        'length-mile-scandinavian',
        'length-mile',
        'length-millimeter',
        'length-yard',
        'mass-gram',
        'mass-kilogram',
        'mass-ounce',
        'mass-pound',
        'mass-stone',
        'temperature-celsius',
        'temperature-fahrenheit',
        'volume-fluid-ounce',
        'volume-gallon',
        'volume-liter',
        'volume-milliliter',
    ];

    /**
     * https://tc39.es/ecma262/#sec-toobject
     * @param arg
     */
    function toObject(arg) {
        if (arg == null) {
            throw new TypeError('undefined/null cannot be converted to object');
        }
        return Object(arg);
    }
    /**
     * https://tc39.es/ecma262/#sec-tostring
     */
    function toString(o) {
        // Only symbol is irregular...
        if (typeof o === 'symbol') {
            throw TypeError('Cannot convert a Symbol value to a string');
        }
        return String(o);
    }
    /**
     * https://tc39.es/ecma402/#sec-getoption
     * @param opts
     * @param prop
     * @param type
     * @param values
     * @param fallback
     */
    function getOption(opts, prop, type, values, fallback) {
        // const descriptor = Object.getOwnPropertyDescriptor(opts, prop);
        var value = opts[prop];
        if (value !== undefined) {
            if (type !== 'boolean' && type !== 'string') {
                throw new TypeError('invalid type');
            }
            if (type === 'boolean') {
                value = Boolean(value);
            }
            if (type === 'string') {
                value = toString(value);
            }
            if (values !== undefined && !values.filter(function (val) { return val == value; }).length) {
                throw new RangeError(value + " is not within " + values.join(', '));
            }
            return value;
        }
        return fallback;
    }
    function setInternalSlot(map, pl, field, value) {
        if (!map.get(pl)) {
            map.set(pl, Object.create(null));
        }
        var slots = map.get(pl);
        slots[field] = value;
    }
    function getInternalSlot(map, pl, field) {
        return getMultiInternalSlots(map, pl, field)[field];
    }
    function getMultiInternalSlots(map, pl) {
        var fields = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            fields[_i - 2] = arguments[_i];
        }
        var slots = map.get(pl);
        if (!slots) {
            throw new TypeError(pl + " InternalSlot has not been initialized");
        }
        return fields.reduce(function (all, f) {
            all[f] = slots[f];
            return all;
        }, Object.create(null));
    }
    function isLiteralPart(patternPart) {
        return patternPart.type === 'literal';
    }
    function partitionPattern(pattern) {
        var result = [];
        var beginIndex = pattern.indexOf('{');
        var endIndex = 0;
        var nextIndex = 0;
        var length = pattern.length;
        while (beginIndex < pattern.length && beginIndex > -1) {
            endIndex = pattern.indexOf('}', beginIndex);
            invariant(endIndex > beginIndex, "Invalid pattern " + pattern);
            if (beginIndex > nextIndex) {
                result.push({
                    type: 'literal',
                    value: pattern.substring(nextIndex, beginIndex),
                });
            }
            result.push({
                type: pattern.substring(beginIndex + 1, endIndex),
                value: undefined,
            });
            nextIndex = endIndex + 1;
            beginIndex = pattern.indexOf('{', nextIndex);
        }
        if (nextIndex < length) {
            result.push({
                type: 'literal',
                value: pattern.substring(nextIndex, length),
            });
        }
        return result;
    }
    var SHORTENED_SACTION_UNITS = SANCTIONED_UNITS.map(function (unit) {
        return unit.replace(/^(.*?)-/, '');
    });

    var __extends = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __assign = (undefined && undefined.__assign) || function () {
        __assign = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function createResolveLocale(getDefaultLocale) {
        var lookupMatcher = createLookupMatcher(getDefaultLocale);
        var bestFitMatcher = createBestFitMatcher(getDefaultLocale);
        /**
         * https://tc39.es/ecma402/#sec-resolvelocale
         */
        return function resolveLocale(availableLocales, requestedLocales, options, relevantExtensionKeys, localeData) {
            var matcher = options.localeMatcher;
            var r;
            if (matcher === 'lookup') {
                r = lookupMatcher(availableLocales, requestedLocales);
            }
            else {
                r = bestFitMatcher(availableLocales, requestedLocales);
            }
            var foundLocale = r.locale;
            var result = { locale: '', dataLocale: foundLocale };
            var supportedExtension = '-u';
            for (var _i = 0, relevantExtensionKeys_1 = relevantExtensionKeys; _i < relevantExtensionKeys_1.length; _i++) {
                var key = relevantExtensionKeys_1[_i];
                var foundLocaleData = localeData[foundLocale];
                invariant(typeof foundLocaleData === 'object' && foundLocaleData !== null, "locale data " + key + " must be an object");
                var keyLocaleData = foundLocaleData[key];
                invariant(Array.isArray(keyLocaleData), "keyLocaleData for " + key + " must be an array");
                var value = keyLocaleData[0];
                invariant(typeof value === 'string' || value === null, 'value must be string or null');
                var supportedExtensionAddition = '';
                if (r.extension) {
                    var requestedValue = unicodeExtensionValue(r.extension, key);
                    if (requestedValue !== undefined) {
                        if (requestedValue !== '') {
                            if (~keyLocaleData.indexOf(requestedValue)) {
                                value = requestedValue;
                                supportedExtensionAddition = "-" + key + "-" + value;
                            }
                        }
                        else if (~requestedValue.indexOf('true')) {
                            value = 'true';
                            supportedExtensionAddition = "-" + key;
                        }
                    }
                }
                if (key in options) {
                    var optionsValue = options[key];
                    invariant(typeof optionsValue === 'string' ||
                        typeof optionsValue === 'undefined' ||
                        optionsValue === null, 'optionsValue must be String, Undefined or Null');
                    if (~keyLocaleData.indexOf(optionsValue)) {
                        if (optionsValue !== value) {
                            value = optionsValue;
                            supportedExtensionAddition = '';
                        }
                    }
                }
                result[key] = value;
                supportedExtension += supportedExtensionAddition;
            }
            if (supportedExtension.length > 2) {
                var privateIndex = foundLocale.indexOf('-x-');
                if (privateIndex === -1) {
                    foundLocale = foundLocale + supportedExtension;
                }
                else {
                    var preExtension = foundLocale.slice(0, privateIndex);
                    var postExtension = foundLocale.slice(privateIndex, foundLocale.length);
                    foundLocale = preExtension + supportedExtension + postExtension;
                }
                foundLocale = Intl.getCanonicalLocales(foundLocale)[0];
            }
            result.locale = foundLocale;
            return result;
        };
    }
    /**
     * https://tc39.es/ecma402/#sec-unicodeextensionvalue
     * @param extension
     * @param key
     */
    function unicodeExtensionValue(extension, key) {
        invariant(key.length === 2, 'key must have 2 elements');
        var size = extension.length;
        var searchValue = "-" + key + "-";
        var pos = extension.indexOf(searchValue);
        if (pos !== -1) {
            var start = pos + 4;
            var end = start;
            var k = start;
            var done = false;
            while (!done) {
                var e = extension.indexOf('-', k);
                var len = void 0;
                if (e === -1) {
                    len = size - k;
                }
                else {
                    len = e - k;
                }
                if (len === 2) {
                    done = true;
                }
                else if (e === -1) {
                    end = size;
                    done = true;
                }
                else {
                    end = e;
                    k = e + 1;
                }
            }
            return extension.slice(start, end);
        }
        searchValue = "-" + key;
        pos = extension.indexOf(searchValue);
        if (pos !== -1 && pos + 3 === size) {
            return '';
        }
        return undefined;
    }
    var UNICODE_EXTENSION_SEQUENCE_REGEX = /-u(?:-[0-9a-z]{2,8})+/gi;
    /**
     * https://tc39.es/ecma402/#sec-bestavailablelocale
     * @param availableLocales
     * @param locale
     */
    function bestAvailableLocale(availableLocales, locale) {
        var candidate = locale;
        while (true) {
            if (~availableLocales.indexOf(candidate)) {
                return candidate;
            }
            var pos = candidate.lastIndexOf('-');
            if (!~pos) {
                return undefined;
            }
            if (pos >= 2 && candidate[pos - 2] === '-') {
                pos -= 2;
            }
            candidate = candidate.slice(0, pos);
        }
    }
    function createLookupMatcher(getDefaultLocale) {
        /**
         * https://tc39.es/ecma402/#sec-lookupmatcher
         */
        return function lookupMatcher(availableLocales, requestedLocales) {
            var result = { locale: '' };
            for (var _i = 0, requestedLocales_1 = requestedLocales; _i < requestedLocales_1.length; _i++) {
                var locale = requestedLocales_1[_i];
                var noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
                var availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
                if (availableLocale) {
                    result.locale = availableLocale;
                    if (locale !== noExtensionLocale) {
                        result.extension = locale.slice(noExtensionLocale.length + 1, locale.length);
                    }
                    return result;
                }
            }
            result.locale = getDefaultLocale();
            return result;
        };
    }
    function createBestFitMatcher(getDefaultLocale) {
        return function bestFitMatcher(availableLocales, requestedLocales) {
            var result = { locale: '' };
            for (var _i = 0, requestedLocales_2 = requestedLocales; _i < requestedLocales_2.length; _i++) {
                var locale = requestedLocales_2[_i];
                var noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
                var availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
                if (availableLocale) {
                    result.locale = availableLocale;
                    if (locale !== noExtensionLocale) {
                        result.extension = locale.slice(noExtensionLocale.length + 1, locale.length);
                    }
                    return result;
                }
            }
            result.locale = getDefaultLocale();
            return result;
        };
    }
    function getLocaleHierarchy(locale) {
        var results = [locale];
        var localeParts = locale.split('-');
        for (var i = localeParts.length; i > 1; i--) {
            results.push(localeParts.slice(0, i - 1).join('-'));
        }
        return results;
    }
    function lookupSupportedLocales(availableLocales, requestedLocales) {
        var subset = [];
        for (var _i = 0, requestedLocales_3 = requestedLocales; _i < requestedLocales_3.length; _i++) {
            var locale = requestedLocales_3[_i];
            var noExtensionLocale = locale.replace(UNICODE_EXTENSION_SEQUENCE_REGEX, '');
            var availableLocale = bestAvailableLocale(availableLocales, noExtensionLocale);
            if (availableLocale) {
                subset.push(availableLocale);
            }
        }
        return subset;
    }
    function supportedLocales(availableLocales, requestedLocales, options) {
        var matcher = 'best fit';
        if (options !== undefined) {
            options = toObject(options);
            matcher = getOption(options, 'localeMatcher', 'string', ['lookup', 'best fit'], 'best fit');
        }
        if (matcher === 'best fit') {
            return lookupSupportedLocales(availableLocales, requestedLocales);
        }
        return lookupSupportedLocales(availableLocales, requestedLocales);
    }
    var MissingLocaleDataError = /** @class */ (function (_super) {
        __extends(MissingLocaleDataError, _super);
        function MissingLocaleDataError() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.type = 'MISSING_LOCALE_DATA';
            return _this;
        }
        return MissingLocaleDataError;
    }(Error));
    function unpackData(locale, localeData, 
    /** By default shallow merge the dictionaries. */
    reducer) {
        if (reducer === void 0) { reducer = function (all, d) { return (__assign(__assign({}, all), d)); }; }
        var localeHierarchy = getLocaleHierarchy(locale);
        var dataToMerge = localeHierarchy
            .map(function (l) { return localeData.data[l]; })
            .filter(Boolean);
        if (!dataToMerge.length) {
            throw new MissingLocaleDataError("Missing locale data for \"" + locale + "\", lookup hierarchy: " + localeHierarchy.join(', '));
        }
        dataToMerge.reverse();
        return dataToMerge.reduce(reducer, {});
    }

    function validateInstance(instance, method) {
        if (!(instance instanceof ListFormat)) {
            throw new TypeError(`Method Intl.ListFormat.prototype.${method} called on incompatible receiver ${String(instance)}`);
        }
    }
    /**
     * https://tc39.es/proposal-intl-list-format/#sec-createstringlistfromiterable
     * @param list list
     */
    function stringListFromIterable(list) {
        if (list === undefined) {
            return [];
        }
        const result = [];
        for (const el of list) {
            if (typeof el !== 'string') {
                throw new TypeError(`array list[${list.indexOf(el)}] is not type String`);
            }
            result.push(el);
        }
        return result;
    }
    function createPartsFromList(internalSlotMap, lf, list) {
        const size = list.length;
        if (size === 0) {
            return [];
        }
        if (size === 2) {
            const pattern = getInternalSlot(internalSlotMap, lf, 'templatePair');
            const first = { type: 'element', value: list[0] };
            const second = { type: 'element', value: list[1] };
            return deconstructPattern(pattern, { '0': first, '1': second });
        }
        const last = {
            type: 'element',
            value: list[size - 1],
        };
        let parts = last;
        let i = size - 2;
        while (i >= 0) {
            let pattern;
            if (i === 0) {
                pattern = getInternalSlot(internalSlotMap, lf, 'templateStart');
            }
            else if (i < size - 2) {
                pattern = getInternalSlot(internalSlotMap, lf, 'templateMiddle');
            }
            else {
                pattern = getInternalSlot(internalSlotMap, lf, 'templateEnd');
            }
            const head = { type: 'element', value: list[i] };
            parts = deconstructPattern(pattern, { '0': head, '1': parts });
            i--;
        }
        return parts;
    }
    function deconstructPattern(pattern, placeables) {
        const patternParts = partitionPattern(pattern);
        const result = [];
        for (const patternPart of patternParts) {
            const { type: part } = patternPart;
            if (isLiteralPart(patternPart)) {
                result.push({
                    type: 'literal',
                    value: patternPart.value,
                });
            }
            else {
                invariant(part in placeables, `${part} is missing from placables`);
                const subst = placeables[part];
                if (Array.isArray(subst)) {
                    result.push(...subst);
                }
                else {
                    result.push(subst);
                }
            }
        }
        return result;
    }
    class ListFormat {
        constructor(locales, options) {
            // test262/test/intl402/ListFormat/constructor/constructor/newtarget-undefined.js
            // Cannot use `new.target` bc of IE11 & TS transpiles it to something else
            const newTarget = this && this instanceof ListFormat ? this.constructor : void 0;
            if (!newTarget) {
                throw new TypeError("Intl.ListFormat must be called with 'new'");
            }
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'initializedListFormat', true);
            const requestedLocales = Intl
                .getCanonicalLocales(locales);
            const opt = Object.create(null);
            const opts = options === undefined ? Object.create(null) : toObject(options);
            const matcher = getOption(opts, 'localeMatcher', 'string', ['best fit', 'lookup'], 'best fit');
            opt.localeMatcher = matcher;
            const { localeData } = ListFormat;
            const r = createResolveLocale(ListFormat.getDefaultLocale)(ListFormat.availableLocales, requestedLocales, opt, ListFormat.relevantExtensionKeys, localeData);
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'locale', r.locale);
            const type = getOption(opts, 'type', 'string', ['conjunction', 'disjunction', 'unit'], 'conjunction');
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'type', type);
            const style = getOption(opts, 'style', 'string', ['long', 'short', 'narrow'], 'long');
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'style', style);
            const { dataLocale } = r;
            const dataLocaleData = localeData[dataLocale];
            const dataLocaleTypes = dataLocaleData[type];
            const templates = dataLocaleTypes[style];
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'templatePair', templates.pair);
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'templateStart', templates.start);
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'templateMiddle', templates.middle);
            setInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'templateEnd', templates.end);
        }
        format(elements) {
            validateInstance(this, 'format');
            let result = '';
            const parts = createPartsFromList(ListFormat.__INTERNAL_SLOT_MAP__, this, stringListFromIterable(elements));
            if (!Array.isArray(parts)) {
                return parts.value;
            }
            for (const p of parts) {
                result += p.value;
            }
            return result;
        }
        formatToParts(elements) {
            validateInstance(this, 'format');
            const parts = createPartsFromList(ListFormat.__INTERNAL_SLOT_MAP__, this, stringListFromIterable(elements));
            if (!Array.isArray(parts)) {
                return [parts];
            }
            const result = [];
            for (const part of parts) {
                result.push(Object.assign({}, part));
            }
            return result;
        }
        resolvedOptions() {
            validateInstance(this, 'resolvedOptions');
            return {
                locale: getInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'locale'),
                type: getInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'type'),
                style: getInternalSlot(ListFormat.__INTERNAL_SLOT_MAP__, this, 'style'),
            };
        }
        static supportedLocalesOf(locales, options) {
            // test262/test/intl402/ListFormat/constructor/supportedLocalesOf/result-type.js
            return supportedLocales(ListFormat.availableLocales, Intl.getCanonicalLocales(locales), options);
        }
        static __addLocaleData(...data) {
            for (const datum of data) {
                const availableLocales = datum.availableLocales;
                availableLocales.forEach(locale => {
                    try {
                        ListFormat.localeData[locale] = unpackData(locale, datum);
                    }
                    catch (e) {
                        // If we can't unpack this data, ignore the locale
                    }
                });
            }
            ListFormat.availableLocales = Object.keys(ListFormat.localeData);
            if (!ListFormat.__defaultLocale) {
                ListFormat.__defaultLocale = ListFormat.availableLocales[0];
            }
        }
        static getDefaultLocale() {
            return ListFormat.__defaultLocale;
        }
    }
    ListFormat.localeData = {};
    ListFormat.availableLocales = [];
    ListFormat.__defaultLocale = 'en';
    ListFormat.relevantExtensionKeys = [];
    ListFormat.polyfilled = true;
    ListFormat.__INTERNAL_SLOT_MAP__ = new WeakMap();
    try {
        // IE11 does not have Symbol
        if (typeof Symbol !== 'undefined') {
            Object.defineProperty(ListFormat.prototype, Symbol.toStringTag, {
                value: 'Intl.ListFormat',
                writable: false,
                enumerable: false,
                configurable: true,
            });
        }
        // https://github.com/tc39/test262/blob/master/test/intl402/ListFormat/constructor/length.js
        Object.defineProperty(ListFormat.prototype.constructor, 'length', {
            value: 0,
            writable: false,
            enumerable: false,
            configurable: true,
        });
        // https://github.com/tc39/test262/blob/master/test/intl402/ListFormat/constructor/supportedLocalesOf/length.js
        Object.defineProperty(ListFormat.supportedLocalesOf, 'length', {
            value: 1,
            writable: false,
            enumerable: false,
            configurable: true,
        });
    }
    catch (e) {
        // Meta fix so we're test262-compliant, not important
    }

    if (!('ListFormat' in Intl)) {
        Object.defineProperty(Intl, 'ListFormat', {
            value: ListFormat,
            writable: true,
            enumerable: false,
            configurable: true,
        });
    }

    /* @generated */
    ListFormat.__addLocaleData({ "data": { "af-NA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } } }, "af": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } } } }, "availableLocales": ["af-NA", "af"] }, { "data": { "agq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["agq"] }, { "data": { "ak": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ak"] }, { "data": { "am": { "conjunction": { "long": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0}, እና {1}", "pair": "{0} እና {1}" }, "short": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0}, እና {1}", "pair": "{0} እና {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}፣ {1}", "end": "{0}, እና {1}", "pair": "{0} እና {1}" } }, "disjunction": { "long": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0} ወይም {1}﻿", "pair": "{0} ወይም {1}﻿" }, "short": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0} ወይም {1}﻿", "pair": "{0} ወይም {1}﻿" }, "narrow": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0} ወይም {1}﻿", "pair": "{0} ወይም {1}﻿" } }, "unit": { "long": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0}፣ {1}", "pair": "{0}፣ {1}" }, "short": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0}፣ {1}", "pair": "{0}፣ {1}" }, "narrow": { "start": "{0}፣ {1}", "middle": "{0}፣ {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["am"] }, { "data": { "ar-AE": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-BH": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-DJ": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-DZ": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-EG": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-EH": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-ER": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-IL": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-IQ": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-JO": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-KM": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-KW": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-LB": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-LY": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-MA": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-MR": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-OM": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-PS": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-QA": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-SA": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-SD": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-SO": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-SS": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-SY": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-TD": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-TN": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar-YE": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } }, "ar": { "conjunction": { "long": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } }, "disjunction": { "long": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "short": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" }, "narrow": { "start": "{0} أو {1}", "middle": "{0} أو {1}", "end": "{0} أو {1}", "pair": "{0} أو {1}" } }, "unit": { "long": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "short": { "start": "{0}، و{1}", "middle": "{0}، و{1}", "end": "{0}، و{1}", "pair": "{0} و{1}" }, "narrow": { "start": "{0} و{1}", "middle": "{0} و{1}", "end": "{0} و{1}", "pair": "{0} و{1}" } } } }, "availableLocales": ["ar-AE", "ar-BH", "ar-DJ", "ar-DZ", "ar-EG", "ar-EH", "ar-ER", "ar-IL", "ar-IQ", "ar-JO", "ar-KM", "ar-KW", "ar-LB", "ar-LY", "ar-MA", "ar-MR", "ar-OM", "ar-PS", "ar-QA", "ar-SA", "ar-SD", "ar-SO", "ar-SS", "ar-SY", "ar-TD", "ar-TN", "ar-YE", "ar"] }, { "data": { "as": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} আৰু {1}", "pair": "{0} আৰু {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} আৰু {1}", "pair": "{0} আৰু {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} বা {1}", "pair": "{0} বা {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} বা {1}", "pair": "{0} বা {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} বা {1}", "pair": "{0} বা {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["as"] }, { "data": { "asa": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["asa"] }, { "data": { "ast": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } } } }, "availableLocales": ["ast"] }, { "data": { "az-Cyrl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "az-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} və {1}", "pair": "{0} və {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} və {1}", "pair": "{0} və {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0} yaxud {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0}, yaxud {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0}, yaxud {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "az": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} və {1}", "pair": "{0} və {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} və {1}", "pair": "{0} və {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0} yaxud {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0}, yaxud {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, yaxud {1}", "pair": "{0}, yaxud {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["az-Cyrl", "az-Latn", "az"] }, { "data": { "bas": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bas"] }, { "data": { "be": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ці {1}", "pair": "{0} ці {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ці {1}", "pair": "{0} ці {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ці {1}", "pair": "{0} ці {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["be"] }, { "data": { "bem": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bem"] }, { "data": { "bez": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bez"] }, { "data": { "bg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} и {1}" } } } }, "availableLocales": ["bg"] }, { "data": { "bm": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bm"] }, { "data": { "bn-IN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} এবং {1}", "pair": "{0} এবং {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} এবং {1}", "pair": "{0} এবং {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "bn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} এবং {1}", "pair": "{0} এবং {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} এবং {1}", "pair": "{0} এবং {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, বা {1}", "pair": "{0} বা {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bn-IN", "bn"] }, { "data": { "bo-IN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "bo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["bo-IN", "bo"] }, { "data": { "br": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ha {1}", "pair": "{0} ha {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} pe {1}", "pair": "{0} pe {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} pe {1}", "pair": "{0} pe {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} pe {1}", "pair": "{0} pe {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["br"] }, { "data": { "brx": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["brx"] }, { "data": { "bs-Cyrl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } }, "bs-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "bs": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } } }, "availableLocales": ["bs-Cyrl", "bs-Latn", "bs"] }, { "data": { "ca-AD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "ca-ES-VALENCIA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "ca-FR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "ca-IT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "ca": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } } }, "availableLocales": ["ca-AD", "ca-ES-VALENCIA", "ca-FR", "ca-IT", "ca"] }, { "data": { "ccp-IN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ccp": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 𑄃𑄳𑄃 {1}", "pair": "{0} 𑄃𑄳𑄃 {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ccp-IN", "ccp"] }, { "data": { "ce": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ce"] }, { "data": { "ceb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, at {1}", "pair": "{0} at {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ug {1}", "pair": "{0} ug {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ceb"] }, { "data": { "cgg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["cgg"] }, { "data": { "chr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ᎠᎴ {1}", "pair": "{0} ᎠᎴ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ᎠᎴᏱᎩ {1}", "pair": "{0} ᎠᎴᏱᎩ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ᎠᎴᏱᎩ {1}", "pair": "{0} ᎠᎴᏱᎩ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ᎠᎴᏱᎩ {1}", "pair": "{0} ᎠᎴᏱᎩ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["chr"] }, { "data": { "ckb-IR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ckb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ckb-IR", "ckb"] }, { "data": { "cs": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} nebo {1}", "pair": "{0} nebo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} nebo {1}", "pair": "{0} nebo {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} nebo {1}", "pair": "{0} nebo {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["cs"] }, { "data": { "cu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["cu"] }, { "data": { "cy": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, a(c) {1}", "pair": "{0} a(c) {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, a(c) {1}", "pair": "{0} a(c) {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} neu {1}", "pair": "{0} neu {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} neu {1}", "pair": "{0} neu {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} neu {1}", "pair": "{0} neu {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["cy"] }, { "data": { "da-GL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} el. {1}", "pair": "{0} el. {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} el. {1}", "pair": "{0} el. {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } } }, "da": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} el. {1}", "pair": "{0} el. {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} el. {1}", "pair": "{0} el. {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } } } }, "availableLocales": ["da-GL", "da"] }, { "data": { "dav": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["dav"] }, { "data": { "de-AT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de-BE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de-CH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de-IT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de-LI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de-LU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } }, "de": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} oder {1}", "pair": "{0} oder {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["de-AT", "de-BE", "de-CH", "de-IT", "de-LI", "de-LU", "de"] }, { "data": { "dje": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["dje"] }, { "data": { "dsb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["dsb"] }, { "data": { "dua": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["dua"] }, { "data": { "dyo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["dyo"] }, { "data": { "dz": { "conjunction": { "long": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" }, "short": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" }, "narrow": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" }, "short": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" }, "narrow": { "start": "{0} དང་ {1}", "middle": "{0} དང་ {1}", "end": "{0} དང་ {1}", "pair": "{0} དང་ {1}" } } } }, "availableLocales": ["dz"] }, { "data": { "ebu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ebu"] }, { "data": { "ee-TG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" } } }, "ee": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, kple {1}", "pair": "{0} kple {1}" } } } }, "availableLocales": ["ee-TG", "ee"] }, { "data": { "el-CY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} και {1}", "pair": "{0} και {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} και {1}", "pair": "{0} και {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "el": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} και {1}", "pair": "{0} και {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} και {1}", "pair": "{0} και {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ή {1}", "pair": "{0} ή {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["el-CY", "el"] }, { "data": { "en-001": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-150": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-AU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BB": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-BZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-CY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-DE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-DG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-DK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-DM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-ER": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-FI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-FJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-FK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-FM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GB": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-GY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-HK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-IE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-IL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-IM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-IN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-IO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-JE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-JM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-KE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-KI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-KN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-KY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-LC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-LR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-LS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MP": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-MY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-NZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-PW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-RW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SB": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-SZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TV": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-TZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-UG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-UM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-US-POSIX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-VC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-VG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-VI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-VU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-WS": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-ZA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-ZM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en-ZW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "en": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["en-001", "en-150", "en-AE", "en-AG", "en-AI", "en-AS", "en-AT", "en-AU", "en-BB", "en-BE", "en-BI", "en-BM", "en-BS", "en-BW", "en-BZ", "en-CA", "en-CC", "en-CH", "en-CK", "en-CM", "en-CX", "en-CY", "en-DE", "en-DG", "en-DK", "en-DM", "en-ER", "en-FI", "en-FJ", "en-FK", "en-FM", "en-GB", "en-GD", "en-GG", "en-GH", "en-GI", "en-GM", "en-GU", "en-GY", "en-HK", "en-IE", "en-IL", "en-IM", "en-IN", "en-IO", "en-JE", "en-JM", "en-KE", "en-KI", "en-KN", "en-KY", "en-LC", "en-LR", "en-LS", "en-MG", "en-MH", "en-MO", "en-MP", "en-MS", "en-MT", "en-MU", "en-MW", "en-MY", "en-NA", "en-NF", "en-NG", "en-NL", "en-NR", "en-NU", "en-NZ", "en-PG", "en-PH", "en-PK", "en-PN", "en-PR", "en-PW", "en-RW", "en-SB", "en-SC", "en-SD", "en-SE", "en-SG", "en-SH", "en-SI", "en-SL", "en-SS", "en-SX", "en-SZ", "en-TC", "en-TK", "en-TO", "en-TT", "en-TV", "en-TZ", "en-UG", "en-UM", "en-US-POSIX", "en-US", "en-VC", "en-VG", "en-VI", "en-VU", "en-WS", "en-ZA", "en-ZM", "en-ZW", "en"] }, { "data": { "eo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["eo"] }, { "data": { "es-419": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-AR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-BO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-BR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-BZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-CL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-CO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-CR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-CU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-DO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} y {1}", "pair": "{0} {1}" } } }, "es-EA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-EC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-GQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-GT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-HN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-IC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-MX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-NI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-PA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-PE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-PH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-PR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-PY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-SV": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-US": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-UY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es-VE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "es": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} y {1}", "pair": "{0} y {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} y {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["es-419", "es-AR", "es-BO", "es-BR", "es-BZ", "es-CL", "es-CO", "es-CR", "es-CU", "es-DO", "es-EA", "es-EC", "es-GQ", "es-GT", "es-HN", "es-IC", "es-MX", "es-NI", "es-PA", "es-PE", "es-PH", "es-PR", "es-PY", "es-SV", "es-US", "es-UY", "es-VE", "es"] }, { "data": { "et": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} või {1}", "pair": "{0} või {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} või {1}", "pair": "{0} või {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} või {1}", "pair": "{0} või {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["et"] }, { "data": { "eu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eta {1}", "pair": "{0} eta {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eta {1}", "pair": "{0} eta {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} edo {1}", "pair": "{0} edo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} edo {1}", "pair": "{0} edo {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} edo {1}", "pair": "{0} edo {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eta {1}", "pair": "{0} eta {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eta {1}", "pair": "{0} eta {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eta {1}", "pair": "{0} eta {1}" } } } }, "availableLocales": ["eu"] }, { "data": { "ewo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ewo"] }, { "data": { "fa-AF": { "conjunction": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "narrow": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}،‏ {1}", "pair": "{0}،‏ {1}" } }, "disjunction": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "narrow": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" } }, "unit": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}،‏ {1}", "pair": "{0}،‏ {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fa": { "conjunction": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "narrow": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}،‏ {1}", "pair": "{0}،‏ {1}" } }, "disjunction": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "narrow": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" } }, "unit": { "long": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}، و {1}", "pair": "{0} و {1}" }, "short": { "start": "{0}،‏ {1}", "middle": "{0}،‏ {1}", "end": "{0}،‏ {1}", "pair": "{0}،‏ {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["fa-AF", "fa"] }, { "data": { "ff-Latn-BF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-CM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-GH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-GM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-GN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-GW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-LR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-MR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-NE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-NG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn-SL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ff": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ff-Latn-BF", "ff-Latn-CM", "ff-Latn-GH", "ff-Latn-GM", "ff-Latn-GN", "ff-Latn-GW", "ff-Latn-LR", "ff-Latn-MR", "ff-Latn-NE", "ff-Latn-NG", "ff-Latn-SL", "ff-Latn", "ff"] }, { "data": { "fi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} tai {1}", "pair": "{0} tai {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} tai {1}", "pair": "{0} tai {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} tai {1}", "pair": "{0} tai {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["fi"] }, { "data": { "fil": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, at {1}", "pair": "{0} at {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, at {1}", "pair": "{0} at {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["fil"] }, { "data": { "fo-DK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ella {1}", "pair": "{0} ella {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["fo-DK", "fo"] }, { "data": { "fr-BE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-BF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-BI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-BJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-BL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-CM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-DJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-DZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-GA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-GF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-GN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-GP": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-GQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-HT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-KM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-LU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-ML": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-MU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-NC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-NE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-PF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-PM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-RE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-RW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-SC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-SN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-SY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-TD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-TG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-TN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-VU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-WF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr-YT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "fr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} et {1}", "pair": "{0} et {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["fr-BE", "fr-BF", "fr-BI", "fr-BJ", "fr-BL", "fr-CA", "fr-CD", "fr-CF", "fr-CG", "fr-CH", "fr-CI", "fr-CM", "fr-DJ", "fr-DZ", "fr-GA", "fr-GF", "fr-GN", "fr-GP", "fr-GQ", "fr-HT", "fr-KM", "fr-LU", "fr-MA", "fr-MC", "fr-MF", "fr-MG", "fr-ML", "fr-MQ", "fr-MR", "fr-MU", "fr-NC", "fr-NE", "fr-PF", "fr-PM", "fr-RE", "fr-RW", "fr-SC", "fr-SN", "fr-SY", "fr-TD", "fr-TG", "fr-TN", "fr-VU", "fr-WF", "fr-YT", "fr"] }, { "data": { "fur": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } } }, "availableLocales": ["fur"] }, { "data": { "fy": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["fy"] }, { "data": { "ga-GB": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ga": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, nó {1}", "pair": "{0} nó {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ga-GB", "ga"] }, { "data": { "gd": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ⁊ {1}", "pair": "{0} ⁊ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} no {1}", "pair": "{0} no {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} no {1}", "pair": "{0} no {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} no {1}", "pair": "{0} no {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} agus {1}", "pair": "{0} agus {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ’s {1}", "pair": "{0} ’s {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["gd"] }, { "data": { "gl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["gl"] }, { "data": { "gsw-FR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } } }, "gsw-LI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } } }, "gsw": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } } } }, "availableLocales": ["gsw-FR", "gsw-LI", "gsw"] }, { "data": { "gu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} અને {1}", "pair": "{0} અને {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} અને {1}", "pair": "{0} અને {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, અથવા {1}", "pair": "{0} અથવા {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} અથવા {1}", "pair": "{0} અથવા {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} અથવા {1}", "pair": "{0} અથવા {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} અને {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["gu"] }, { "data": { "guz": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["guz"] }, { "data": { "gv": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["gv"] }, { "data": { "ha-GH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ha-NE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ha": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} da {1}", "pair": "{0} da {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ko {1}", "pair": "{0} ko {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ha-GH", "ha-NE", "ha"] }, { "data": { "haw": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["haw"] }, { "data": { "he": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ו{1}", "pair": "{0} ו{1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ו{1}", "pair": "{0} ו{1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ו{1}", "pair": "{0} ו{1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, או {1}", "pair": "{0} או {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} או {1}", "pair": "{0} או {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} או {1}", "pair": "{0} או {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ו{1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["he"] }, { "data": { "hi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, और {1}", "pair": "{0} और {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} और {1}", "pair": "{0} और {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} और {1}", "pair": "{0} और {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} या {1}", "pair": "{0} या {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} या {1}", "pair": "{0} या {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} या {1}", "pair": "{0} या {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, और {1}", "pair": "{0} और {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["hi"] }, { "data": { "hr-BA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "hr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["hr-BA", "hr"] }, { "data": { "hsb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["hsb"] }, { "data": { "hu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vagy {1}", "pair": "{0} vagy {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vagy {1}", "pair": "{0} vagy {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vagy {1}", "pair": "{0} vagy {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} és {1}", "pair": "{0} és {1}" } } } }, "availableLocales": ["hu"] }, { "data": { "hy": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} և {1}", "pair": "{0} և {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} և {1}", "pair": "{0} և {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} կամ {1}", "pair": "{0} կամ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} կամ {1}", "pair": "{0} կամ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} կամ {1}", "pair": "{0} կամ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} և {1}", "pair": "{0} և {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} և {1}", "pair": "{0} և {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["hy"] }, { "data": { "ia": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ia"] }, { "data": { "id": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, dan {1}", "pair": "{0} dan {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["id"] }, { "data": { "ig": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, na {1}", "pair": "{0} na {1}" } } } }, "availableLocales": ["ig"] }, { "data": { "ii": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ii"] }, { "data": { "is": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eða {1}", "pair": "{0} eða {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eða {1}", "pair": "{0} eða {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eða {1}", "pair": "{0} eða {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } } } }, "availableLocales": ["is"] }, { "data": { "it-CH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "it-SM": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "it-VA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "it": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["it-CH", "it-SM", "it-VA", "it"] }, { "data": { "ja": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、{1}", "pair": "{0}、{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、{1}", "pair": "{0}、{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、{1}", "pair": "{0}、{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、または{1}", "pair": "{0}または{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、または{1}", "pair": "{0}または{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}、または{1}", "pair": "{0}または{1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } } }, "availableLocales": ["ja"] }, { "data": { "jgo": { "conjunction": { "long": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" }, "short": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" }, "narrow": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" }, "short": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" }, "narrow": { "start": "{0}, ŋ́gɛ {1}", "middle": "{0}, ŋ́gɛ {1}", "end": "{0}, ḿbɛn ŋ́gɛ {1}", "pair": "{0} pɔp {1}" } } } }, "availableLocales": ["jgo"] }, { "data": { "jmc": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["jmc"] }, { "data": { "jv": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, lan {1}", "pair": "{0} lan {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, lan {1}", "pair": "{0} lan {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, lan {1}", "pair": "{0} lan {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utowo {1}", "pair": "{0} utowo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utowo {1}", "pair": "{0} utowo {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utowo {1}", "pair": "{0} utowo {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["jv"] }, { "data": { "ka": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} და {1}", "pair": "{0} და {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} და {1}", "pair": "{0} და {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} და {1}", "pair": "{0} და {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ან {1}", "pair": "{0} ან {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ან {1}", "pair": "{0} ან {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ან {1}", "pair": "{0} ან {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ka"] }, { "data": { "kab": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kab"] }, { "data": { "kam": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kam"] }, { "data": { "kde": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kde"] }, { "data": { "kea": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} o {1}", "pair": "{0} o {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kea"] }, { "data": { "khq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["khq"] }, { "data": { "ki": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ki"] }, { "data": { "kk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} және {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} және {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} және {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, не болмаса {1}", "pair": "{0} не {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, не болмаса {1}", "pair": "{0} не {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, не болмаса {1}", "pair": "{0} не {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["kk"] }, { "data": { "kkj": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kkj"] }, { "data": { "kl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kl"] }, { "data": { "kln": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kln"] }, { "data": { "km": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} និង {1}", "pair": "{0} និង​{1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} និង {1}", "pair": "{0} និង​{1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} និង {1}", "pair": "{0} និង​{1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ឬ {1}", "pair": "{0} ឬ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ឬ {1}", "pair": "{0} ឬ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ឬ {1}", "pair": "{0} ឬ {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["km"] }, { "data": { "kn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ಮತ್ತು {1}", "pair": "{0} ಮತ್ತು {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ಮತ್ತು {1}", "pair": "{0} ಮತ್ತು {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ಅಥವಾ {1}", "pair": "{0} ಅಥವಾ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ಅಥವಾ {1}", "pair": "{0} ಅಥವಾ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ಅಥವಾ {1}", "pair": "{0} ಅಥವಾ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["kn"] }, { "data": { "ko-KP": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ko": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 및 {1}", "pair": "{0} 및 {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} 또는 {1}", "pair": "{0} 또는 {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ko-KP", "ko"] }, { "data": { "kok": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} & {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kok"] }, { "data": { "ks": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ks"] }, { "data": { "ksb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ksb"] }, { "data": { "ksf": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ksf"] }, { "data": { "ksh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ksh"] }, { "data": { "ku": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} û {1}", "pair": "{0} û {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} û {1}", "pair": "{0} û {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} û {1}", "pair": "{0} û {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} an {1}", "pair": "{0} an {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} an {1}", "pair": "{0} an {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} an {1}", "pair": "{0} an {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} û {1}", "pair": "{0} û {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} û {1}", "pair": "{0} û {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ku"] }, { "data": { "kw": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["kw"] }, { "data": { "ky": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} жана {1}", "pair": "{0} жана {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} жана {1}", "pair": "{0} жана {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} жана {1}", "pair": "{0} жана {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, же {1}", "pair": "{0} же {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, же {1}", "pair": "{0} же {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, же {1}", "pair": "{0} же {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ky"] }, { "data": { "lag": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["lag"] }, { "data": { "lb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a(n) {1}", "pair": "{0} a(n) {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a(n) {1}", "pair": "{0} a(n) {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a(n) {1}", "pair": "{0} a(n) {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["lb"] }, { "data": { "lg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["lg"] }, { "data": { "lkt": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["lkt"] }, { "data": { "ln-AO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ln-CF": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ln-CG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ln": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ln-AO", "ln-CF", "ln-CG", "ln"] }, { "data": { "lo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} ແລະ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} ແລະ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} ແລະ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ຫຼື {1}", "pair": "{0} ຫຼື {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ຫຼື {1}", "pair": "{0} ຫຼື {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ຫຼື {1}", "pair": "{0} ຫຼື {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["lo"] }, { "data": { "lrc-IQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "lrc": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["lrc-IQ", "lrc"] }, { "data": { "lt": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ir {1}", "pair": "{0} ir {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ir {1}", "pair": "{0} ir {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ir {1}", "pair": "{0} ir {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ar {1}", "pair": "{0} ar {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ar {1}", "pair": "{0} ar {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ar {1}", "pair": "{0} ar {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} ir {1}", "pair": "{0} ir {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["lt"] }, { "data": { "lu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["lu"] }, { "data": { "luo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["luo"] }, { "data": { "luy": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["luy"] }, { "data": { "lv": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vai {1}", "pair": "{0} vai {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vai {1}", "pair": "{0} vai {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} vai {1}", "pair": "{0} vai {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} un {1}", "pair": "{0} un {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["lv"] }, { "data": { "mas-TZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "mas": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mas-TZ", "mas"] }, { "data": { "mer": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mer"] }, { "data": { "mfe": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mfe"] }, { "data": { "mg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mg"] }, { "data": { "mgh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mgh"] }, { "data": { "mgo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mgo"] }, { "data": { "mi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mi"] }, { "data": { "mk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } } }, "availableLocales": ["mk"] }, { "data": { "ml": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} എന്നിവ", "pair": "{0} കൂടാതെ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} എന്നിവ", "pair": "{0} കൂടാതെ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} എന്നിവ", "pair": "{0} കൂടാതെ {1}" } }, "disjunction": { "long": { "start": "{0}, {1} എന്നിവ", "middle": "{0}, {1} എന്നിവ", "end": "{0}, അല്ലെങ്കിൽ {1}", "pair": "{0} അല്ലെങ്കിൽ {1}" }, "short": { "start": "{0}, {1} എന്നിവ", "middle": "{0}, {1} എന്നിവ", "end": "{0}, അല്ലെങ്കിൽ {1}", "pair": "{0} അല്ലെങ്കിൽ {1}" }, "narrow": { "start": "{0}, {1} എന്നിവ", "middle": "{0}, {1} എന്നിവ", "end": "{0}, അല്ലെങ്കിൽ {1}", "pair": "{0} അല്ലെങ്കിൽ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} കൂടാതെ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} കൂടാതെ {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ml"] }, { "data": { "mn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} зэргийн аль нэг", "pair": "{0} эсвэл {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} зэргийн аль нэг", "pair": "{0} эсвэл {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1} зэргийн аль нэг", "pair": "{0} эсвэл {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["mn"] }, { "data": { "mr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} आणि {1}", "pair": "{0} आणि {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} आणि {1}", "pair": "{0} आणि {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} आणि {1}", "pair": "{0} आणि {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, किंवा {1}", "pair": "{0} किंवा {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, किंवा {1}", "pair": "{0} किंवा {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, किंवा {1}", "pair": "{0} किंवा {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["mr"] }, { "data": { "ms-BN": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ms-SG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ms": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, atau {1}", "pair": "{0} atau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dan {1}", "pair": "{0} dan {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ms-BN", "ms-SG", "ms"] }, { "data": { "mt": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, u {1}", "pair": "{0} u {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, u {1}", "pair": "{0} u {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, u {1}", "pair": "{0} u {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, u {1}", "pair": "{0} u {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, u {1}", "pair": "{0} u {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mt"] }, { "data": { "mua": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mua"] }, { "data": { "my": { "conjunction": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့် {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့် {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့် {1}" } }, "disjunction": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} သို့မဟုတ် {1}", "pair": "{0} သို့မဟုတ် {1}" }, "short": { "start": "{0} ၊ {1}", "middle": "{0} {1}", "end": "{0} သို့မဟုတ် {1}", "pair": "{0} သို့မဟုတ် {1}" }, "narrow": { "start": "{0} ၊ {1}", "middle": "{0} {1}", "end": "{0} သို့မဟုတ် {1}", "pair": "{0} သို့မဟုတ် {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့်{1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့် {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0}နှင့် {1}", "pair": "{0}နှင့် {1}" } } } }, "availableLocales": ["my"] }, { "data": { "mzn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["mzn"] }, { "data": { "naq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["naq"] }, { "data": { "nb-SJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nb": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nb-SJ", "nb"] }, { "data": { "nd": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nd"] }, { "data": { "nds-NL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nds": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nds-NL", "nds"] }, { "data": { "ne-IN": { "conjunction": { "long": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0} र {1}", "pair": "{0} र {1}" }, "short": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0} र {1}", "pair": "{0} र {1}" }, "narrow": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" } }, "unit": { "long": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0},{1}", "pair": "{0},{1}" }, "short": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0},{1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0}{1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ne": { "conjunction": { "long": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0} र {1}", "pair": "{0} र {1}" }, "short": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0} र {1}", "pair": "{0} र {1}" }, "narrow": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, वा {1}", "pair": "{0} वा {1}" } }, "unit": { "long": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0},{1}", "pair": "{0},{1}" }, "short": { "start": "{0},{1}", "middle": "{0}, {1}", "end": "{0},{1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0}{1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ne-IN", "ne"] }, { "data": { "nl-AW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl-BE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl-BQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl-CW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl-SR": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl-SX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "nl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} of {1}", "pair": "{0} of {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} en {1}", "pair": "{0} en {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nl-AW", "nl-BE", "nl-BQ", "nl-CW", "nl-SR", "nl-SX", "nl"] }, { "data": { "nmg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nmg"] }, { "data": { "nn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} og {1}", "pair": "{0} og {1}" } } } }, "availableLocales": ["nn"] }, { "data": { "nnh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nnh"] }, { "data": { "nus": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nus"] }, { "data": { "nyn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["nyn"] }, { "data": { "om-KE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "om": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["om-KE", "om"] }, { "data": { "or": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ଓ {1}", "pair": "{0} ଓ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ଓ {1}", "pair": "{0} ଓ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ଓ {1}", "pair": "{0} ଓ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} କିମ୍ବା {1}", "pair": "{0} କିମ୍ବା {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} କିମ୍ବା {1}", "pair": "{0} କିମ୍ବା {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} କିମ୍ବା {1}", "pair": "{0} କିମ୍ବା {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["or"] }, { "data": { "os-RU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" } } }, "os": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ӕмӕ {1}", "pair": "{0} ӕмӕ {1}" } } } }, "availableLocales": ["os-RU", "os"] }, { "data": { "pa-Arab": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "pa-Guru": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ਅਤੇ {1}", "pair": "{0} ਅਤੇ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ਅਤੇ {1}", "pair": "{0} ਅਤੇ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} ਜਾਂ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ਜਾਂ {1}", "pair": "{0} ਜਾਂ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ਜਾਂ {1}", "pair": "{0} ਜਾਂ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "pa": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ਅਤੇ {1}", "pair": "{0} ਅਤੇ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ਅਤੇ {1}", "pair": "{0} ਅਤੇ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} ਜਾਂ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ਜਾਂ {1}", "pair": "{0} ਜਾਂ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ਜਾਂ {1}", "pair": "{0} ਜਾਂ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["pa-Arab", "pa-Guru", "pa"] }, { "data": { "pl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} lub {1}", "pair": "{0} lub {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} lub {1}", "pair": "{0} lub {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} lub {1}", "pair": "{0} lub {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } } }, "availableLocales": ["pl"] }, { "data": { "prg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["prg"] }, { "data": { "ps-PK": { "conjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0} او {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0} او {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0}، {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} او {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} و {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ps": { "conjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0} او {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0} او {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، او {1}", "pair": "{0}، {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} او {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} و {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ps-PK", "ps"] }, { "data": { "pt-AO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-CH": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-CV": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-GQ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-GW": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-LU": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-MO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-MZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-PT": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-ST": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt-TL": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "pt": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ou {1}", "pair": "{0} ou {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["pt-AO", "pt-CH", "pt-CV", "pt-GQ", "pt-GW", "pt-LU", "pt-MO", "pt-MZ", "pt-PT", "pt-ST", "pt-TL", "pt"] }, { "data": { "qu-BO": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "qu-EC": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "qu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, utaq {1}", "pair": "{0} utaq {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["qu-BO", "qu-EC", "qu"] }, { "data": { "rm": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["rm"] }, { "data": { "rn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["rn"] }, { "data": { "ro-MD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} și {1}", "pair": "{0} și {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} și {1}", "pair": "{0} și {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} și {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ro": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} și {1}", "pair": "{0} și {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} și {1}", "pair": "{0} și {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} sau {1}", "pair": "{0} sau {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} și {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ro-MD", "ro"] }, { "data": { "rof": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["rof"] }, { "data": { "root": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["root"] }, { "data": { "ru-BY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ru-KG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ru-KZ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ru-MD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ru-UA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ru": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ru-BY", "ru-KG", "ru-KZ", "ru-MD", "ru-UA", "ru"] }, { "data": { "rw": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["rw"] }, { "data": { "rwk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["rwk"] }, { "data": { "sah": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} уонна {1}", "pair": "{0} уонна {1}" } } } }, "availableLocales": ["sah"] }, { "data": { "saq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["saq"] }, { "data": { "sbp": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["sbp"] }, { "data": { "sd": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}، ۽ {1}", "pair": "{0} ۽ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}، ۽ {1}", "pair": "{0} ۽ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, يا {1}", "pair": "{0} يا {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, يا {1}", "pair": "{0} يا {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, يا {1}", "pair": "{0} يا {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["sd"] }, { "data": { "se-FI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "se-SE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "se": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ja {1}", "pair": "{0} ja {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["se-FI", "se-SE", "se"] }, { "data": { "seh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["seh"] }, { "data": { "ses": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ses"] }, { "data": { "sg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["sg"] }, { "data": { "shi-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "shi-Tfng": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "shi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["shi-Latn", "shi-Tfng", "shi"] }, { "data": { "si": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, හෝ {1}", "pair": "{0} හෝ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, හෝ {1}", "pair": "{0} හෝ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, හෝ {1}", "pair": "{0} හෝ {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, සහ {1}", "pair": "{0} සහ {1}" } } } }, "availableLocales": ["si"] }, { "data": { "sk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} a {1}", "pair": "{0} a {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} alebo {1}", "pair": "{0} alebo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} alebo {1}", "pair": "{0} alebo {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} alebo {1}", "pair": "{0} alebo {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["sk"] }, { "data": { "sl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ali {1}", "pair": "{0} ali {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ali {1}", "pair": "{0} ali {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ali {1}", "pair": "{0} ali {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} in {1}", "pair": "{0} in {1}" } } } }, "availableLocales": ["sl"] }, { "data": { "smn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["smn"] }, { "data": { "sn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["sn"] }, { "data": { "so-DJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} iyo {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "so-ET": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} iyo {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "so-KE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} iyo {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "so": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} iyo {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} & {1}", "pair": "{0} & {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ama {1}", "pair": "{0} ama {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0} iyo {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["so-DJ", "so-ET", "so-KE", "so"] }, { "data": { "sq-MK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "sq-XK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } }, "sq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} dhe {1}", "pair": "{0} dhe {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ose {1}", "pair": "{0} ose {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} e {1}", "pair": "{0} e {1}" } } } }, "availableLocales": ["sq-MK", "sq-XK", "sq"] }, { "data": { "sr-Cyrl-BA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } }, "sr-Cyrl-ME": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } }, "sr-Cyrl-XK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } }, "sr-Cyrl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } }, "sr-Latn-BA": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "sr-Latn-ME": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "sr-Latn-XK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "sr-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ili {1}", "pair": "{0} ili {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} i {1}", "pair": "{0} i {1}" } } }, "sr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} или {1}", "pair": "{0} или {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} и {1}", "pair": "{0} и {1}" } } } }, "availableLocales": ["sr-Cyrl-BA", "sr-Cyrl-ME", "sr-Cyrl-XK", "sr-Cyrl", "sr-Latn-BA", "sr-Latn-ME", "sr-Latn-XK", "sr-Latn", "sr"] }, { "data": { "sv-AX": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "sv-FI": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "sv": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} och {1}", "pair": "{0} och {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} eller {1}", "pair": "{0} eller {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["sv-AX", "sv-FI", "sv"] }, { "data": { "sw-CD": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} au {1}", "pair": "{0} au {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" } } }, "sw-KE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} au {1}", "pair": "{0} au {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" } } }, "sw-UG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} au {1}", "pair": "{0} au {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" } } }, "sw": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} au {1}", "pair": "{0} au {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, au {1}", "pair": "{0} au {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} na {1}", "pair": "{0} na {1}" } } } }, "availableLocales": ["sw-CD", "sw-KE", "sw-UG", "sw"] }, { "data": { "ta-LK": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ta-MY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ta-SG": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "ta": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} அல்லது {1}", "pair": "{0} அல்லது {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} மற்றும் {1}", "pair": "{0} மற்றும் {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["ta-LK", "ta-MY", "ta-SG", "ta"] }, { "data": { "te": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} మరియు {1}", "pair": "{0} మరియు {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} మరియు {1}", "pair": "{0} మరియు {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} లేదా {1}", "pair": "{0} లేదా {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} లేదా {1}", "pair": "{0} లేదా {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} లేదా {1}", "pair": "{0} లేదా {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["te"] }, { "data": { "teo-KE": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "teo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["teo-KE", "teo"] }, { "data": { "tg": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["tg"] }, { "data": { "th": { "conjunction": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} และ{1}", "pair": "{0}และ{1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} และ{1}", "pair": "{0}และ{1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} และ{1}", "pair": "{0}และ{1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} หรือ {1}", "pair": "{0} หรือ {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} หรือ {1}", "pair": "{0}หรือ{1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} หรือ {1}", "pair": "{0}หรือ{1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} และ {1}", "pair": "{0} และ {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} และ {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["th"] }, { "data": { "ti-ER": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "ti": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["ti-ER", "ti"] }, { "data": { "tk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} we {1}", "pair": "{0} we {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} we {1}", "pair": "{0} we {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ýa-da {1}", "pair": "{0} ýa-da {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ýa-da {1}", "pair": "{0} ýa-da {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ýa-da {1}", "pair": "{0} ýa-da {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["tk"] }, { "data": { "to": { "conjunction": { "long": { "start": "{0} mo {1}", "middle": "{0} mo {1}", "end": "{0} mo {1}", "pair": "{0} mo {1}" }, "short": { "start": "{0} mo {1}", "middle": "{0} mo {1}", "end": "{0} mo {1}", "pair": "{0} mo {1}" }, "narrow": { "start": "{0} mo {1}", "middle": "{0} mo {1}", "end": "{0} mo {1}", "pair": "{0} mo {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, pē {1}", "pair": "{0} pē {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, pē {1}", "pair": "{0} pē {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, pē {1}", "pair": "{0} pē {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} mo e {1}", "pair": "{0} mo e {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} mo e {1}", "pair": "{0} mo e {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} mo e {1}", "pair": "{0} mo e {1}" } } } }, "availableLocales": ["to"] }, { "data": { "tr-CY": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ve {1}", "pair": "{0} ve {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ve {1}", "pair": "{0} ve {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "tr": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ve {1}", "pair": "{0} ve {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} ve {1}", "pair": "{0} ve {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} veya {1}", "pair": "{0} veya {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["tr-CY", "tr"] }, { "data": { "tt": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} һәм {1}", "pair": "{0} һәм {1}" } } } }, "availableLocales": ["tt"] }, { "data": { "twq": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["twq"] }, { "data": { "tzm": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["tzm"] }, { "data": { "ug": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, and {1}", "pair": "{0} and {1}" } } } }, "availableLocales": ["ug"] }, { "data": { "uk": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} або {1}", "pair": "{0} або {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} або {1}", "pair": "{0} або {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} або {1}", "pair": "{0} або {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} і {1}", "pair": "{0} і {1}" } } } }, "availableLocales": ["uk"] }, { "data": { "ur-IN": { "conjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، {1}", "pair": "{0}، {1}" } }, "disjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{1}، {0}", "pair": "{1}، {0}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{1}، {0}", "pair": "{1}، {0}" }, "narrow": { "start": "{1} {0}", "middle": "{1} {0}", "end": "{1} {0}", "pair": "{1} {0}" } } }, "ur": { "conjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، {1}", "pair": "{0}، {1}" } }, "disjunction": { "long": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، یا {1}", "pair": "{0} یا {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}، اور {1}", "pair": "{0}، {1}" }, "short": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" }, "narrow": { "start": "{0}، {1}", "middle": "{0}، {1}", "end": "{0}، اور {1}", "pair": "{0} اور {1}" } } } }, "availableLocales": ["ur-IN", "ur"] }, { "data": { "uz-Arab": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "uz-Cyrl": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "uz-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} va {1}", "pair": "{0} va {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} va {1}", "pair": "{0} va {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } }, "uz": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} va {1}", "pair": "{0} va {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} va {1}", "pair": "{0} va {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} yoki {1}", "pair": "{0} yoki {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["uz-Arab", "uz-Cyrl", "uz-Latn", "uz"] }, { "data": { "vai-Latn": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "vai-Vaii": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "vai": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["vai-Latn", "vai-Vaii", "vai"] }, { "data": { "vi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} và {1}", "pair": "{0} và {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} và {1}", "pair": "{0} và {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} hoặc {1}", "pair": "{0} hoặc {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} hoặc {1}", "pair": "{0} hoặc {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} hoặc {1}", "pair": "{0} hoặc {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} và {1}", "pair": "{0} và {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} và {1}", "pair": "{0} và {1}" }, "narrow": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" } } } }, "availableLocales": ["vi"] }, { "data": { "vo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["vo"] }, { "data": { "vun": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["vun"] }, { "data": { "wae": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} und {1}", "pair": "{0} und {1}" } } } }, "availableLocales": ["wae"] }, { "data": { "wo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["wo"] }, { "data": { "xh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["xh"] }, { "data": { "xog": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["xog"] }, { "data": { "yav": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["yav"] }, { "data": { "yi": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} און {1}", "pair": "{0} און {1}" } } } }, "availableLocales": ["yi"] }, { "data": { "yo-BJ": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } }, "yo": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["yo-BJ", "yo"] }, { "data": { "yue-Hans": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "yue-Hant": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "yue": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}同{1}", "pair": "{0}同{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0} 或 {1}", "pair": "{0} 或 {1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } } }, "availableLocales": ["yue-Hans", "yue-Hant", "yue"] }, { "data": { "zgh": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["zgh"] }, { "data": { "zh-Hans-HK": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "short": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hans-MO": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "short": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hans-SG": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "short": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hans": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "short": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hant-HK": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hant-MO": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}及{1}", "pair": "{0}及{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh-Hant": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "short": { "start": "{0} {1}", "middle": "{0} {1}", "end": "{0} {1}", "pair": "{0} {1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } }, "zh": { "conjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}和{1}", "pair": "{0}和{1}" } }, "disjunction": { "long": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "short": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" }, "narrow": { "start": "{0}、{1}", "middle": "{0}、{1}", "end": "{0}或{1}", "pair": "{0}或{1}" } }, "unit": { "long": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "short": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" }, "narrow": { "start": "{0}{1}", "middle": "{0}{1}", "end": "{0}{1}", "pair": "{0}{1}" } } } }, "availableLocales": ["zh-Hans-HK", "zh-Hans-MO", "zh-Hans-SG", "zh-Hans", "zh-Hant-HK", "zh-Hant-MO", "zh-Hant", "zh"] }, { "data": { "zu": { "conjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ne-{1}", "pair": "{0} ne-{1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, ne-{1}", "pair": "{0} ne-{1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" } }, "disjunction": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, or {1}", "pair": "{0} or {1}" } }, "unit": { "long": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "short": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0}, {1}", "pair": "{0}, {1}" }, "narrow": { "start": "{0}, {1}", "middle": "{0}, {1}", "end": "{0} {1}", "pair": "{0}, {1}" } } } }, "availableLocales": ["zu"] });

})));
//# sourceMappingURL=polyfill-with-locales-for-test262.js.map
